@@ -18,8 +18,10 @@ class TaskDescription:
 @dataclasses.dataclass
 class JobDescription:
     tasks: List[TaskDescription]
+    on_error: Optional[List[TaskDescription]]
 
     @classmethod
     def from_dict(cls, data: typing.Dict):
-        c = {'tasks': [TaskDescription.from_dict(t) for t in data['tasks']]}
+        c = {'tasks': [TaskDescription.from_dict(t) for t in data['tasks']],
+             'on_error': data.get('on_error', None) and [TaskDescription.from_dict(t) for t in data.get('on_error')]}
         return cls(**c)
