@@ -35,6 +35,13 @@ class JobRunner:
                 task.execute(context, dry_run)
             except Exception as e:
                 logger.exception(f"Failed to run a task {task}: {e}")
+                self.on_error(context, e)
                 raise
 
         logger.info("Completed.")
+
+    def on_error(self, context, e):
+        context.add_environment_variable('IRISML_EXCEPTION', e)
+        for task in self._job.on_error:
+            logger.info(f"Running an error handler: {task}")
+            task.execute(context)
