@@ -1,11 +1,13 @@
 import collections
+import copy
 import dataclasses
+import pathlib
 import pickle
 import threading
 import typing
 import unittest
 import torch
-from irisml.core.cache_manager import CachedOutputs, StorageManager
+from irisml.core.cache_manager import CachedOutputs, StorageManager, AzureBlobStorageManager, FileSystemStorageManager
 from irisml.core.hash_generator import HashGenerator
 from irisml.core.variable import Variable
 
@@ -160,3 +162,15 @@ class TestCachedOutputs(unittest.TestCase):
 
         self.assertEqual(c.elem0, 12345)
         self.assertEqual(c.elem1, '12345')
+
+
+class TestStorageManager(unittest.TestCase):
+    def test_azure_blob_manager_serializable(self):
+        manager = AzureBlobStorageManager('https://myaccount.blob.core.windows.net/mycontainer')
+        copied = copy.deepcopy(manager)
+        self.assertIsNotNone(copied)
+
+    def test_file_system_manager_serializable(self):
+        manager = FileSystemStorageManager(pathlib.Path('/tmp/irisml'))
+        copied = copy.deepcopy(manager)
+        self.assertIsNotNone(copied)
