@@ -2,7 +2,7 @@ import dataclasses
 import sys
 import typing
 import unittest
-from typing import Dict, List, Optional
+from typing import Dict, List, Tuple, Optional
 from irisml.core import Context, TaskBase, TaskDescription
 from irisml.core.task import Task
 from irisml.core.variable import OutputVariable
@@ -19,14 +19,16 @@ class TestTask(unittest.TestCase):
             int_var: int
             str_var: str
             optional_int_var: Optional[int]
+            tuple_var: Tuple[str, str]
             int_list_var: List[int]
             str_dict_var: Dict[str, str]
             nested: ChildConfig
             optional_nested: Optional[ChildConfig]
+            list_of_tuple: List[Tuple[str, float]]
             int_default_var: int = 42
 
-        result = Task._load_config(Config, {'int_var': 12, 'str_var': '12', 'optional_int_var': 24, 'int_list_var': [1, 2, 3], 'str_dict_var': {'k': 'v', 'k2': 'v2'},
-                                            'nested': {'int_var': 123}, 'optional_nested': {'int_var': 345}})
+        result = Task._load_config(Config, {'int_var': 12, 'str_var': '12', 'optional_int_var': 24, 'tuple_var': ('k', 'v'), 'int_list_var': [1, 2, 3], 'str_dict_var': {'k': 'v', 'k2': 'v2'},
+                                            'nested': {'int_var': 123}, 'optional_nested': {'int_var': 345}, 'list_of_tuple': [('k1', 1), ('k2', 2.5)]})
         self.assertEqual(result.nested, ChildConfig(int_var=123))
         self.assertEqual(result.optional_nested, ChildConfig(int_var=345))
         self.assertEqual(result.int_var, 12)
@@ -35,6 +37,8 @@ class TestTask(unittest.TestCase):
         self.assertEqual(result.int_list_var, [1, 2, 3])
         self.assertEqual(result.str_dict_var, {'k': 'v', 'k2': 'v2'})
         self.assertEqual(result.int_default_var, 42)
+        self.assertEqual(result.tuple_var, ('k', 'v'))
+        self.assertEqual(result.list_of_tuple, [('k1', 1), ('k2', 2.5)])
 
     def test_output_variable_in_config(self):
         @dataclasses.dataclass
